package my.petstore.web;

import java.util.ArrayList;

import javax.servlet.http.HttpSession;

import my.petstore.entity.Item;
import my.petstore.entity.Product;
import my.petstore.service.ProductService;
import my.petstore.util.PagedListUtil;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.support.PagedListHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

@Controller
public class ProductController {

    @Autowired
    private ProductService productService;

    @RequestMapping(value="/products", method=RequestMethod.GET)
    public String handleRequest(@RequestParam(required=false) String page, HttpSession session, Model model) {
        PagedListHolder itemList = (PagedListHolder) session.getAttribute("ViewProductAction_itemList");
        Product product = (Product) session.getAttribute("ViewProductAction_product");

        PagedListUtil.movePage(itemList, page);

        model.addAttribute("itemList", itemList);
        model.addAttribute("product", product);
        return "Product";
    }

    @RequestMapping(value="/products/{productId}", method=RequestMethod.GET)
    public String handleRequest(@PathVariable("productId") Integer productId, @RequestParam(required=false) String page, HttpSession session, Model model) {
        Product product = productService.getProduct(productId);
        PagedListHolder itemList = new PagedListHolder(new ArrayList<Item>(product.getItems()));
        itemList.setPageSize(4);
        session.setAttribute("ViewProductAction_itemList", itemList);
        session.setAttribute("ViewProductAction_product", product);

        model.addAttribute("itemList", itemList);
        model.addAttribute("product", product);
        return "Product";
    }
}
